@@ -45,9 +45,6 @@ def check_for_graphviz(args):
 
 
 def append_python_path(cwd=None):
-    """append_python_path(cwd) -> None
-    Append provided (or actual cwd if not provided) path to python path.
-    """
     if cwd:
         sys.path.append(cwd)
     else:
@@ -90,7 +87,7 @@ def run_tasks(mkfile, args):
                 mkfile.SETTINGS['default task'].run(force=args.force,
                                     dependency_force=args.dependency_force)
                 return 'run default'
-        except AttributeError:
+        except (AttributeError, KeyError):
             return list_all_tasks()
 
     def run_all_inputet_tasks():
