@@ -6,15 +6,18 @@ import tempfile
 import logging
 from time import sleep
 
-from pymk.script import import_mkfile, run_tasks, TaskData
+from pymk.script import import_mkfile, run_tasks, TaskMeta
 from pymk.extra import touch
 
+
 class ArgsMockup(object):
     def __init__(self):
         self.all = False
         self.task = []
         self.force = False
         self.dependency_force = False
+        self.graph = False
+
 
 class PymkTestCase(unittest.TestCase):
     def setUp(self):
@@ -23,7 +26,8 @@ class PymkTestCase(unittest.TestCase):
         sys.path.append(self._actual_path)
         os.chdir(self._actual_path)
         self._args = ArgsMockup()
-        logging.getLogger('pymk').info('=== (%s) %s ===' %(self.__class__.__name__, self._testMethodName))
+        logging.getLogger('pymk').info('=== (%s) %s ===' % (
+            self.__class__.__name__, self._testMethodName))
 
     def tearDown(self):
         sys.path.remove(self._actual_path)
@@ -35,18 +39,17 @@ class PymkTestCase(unittest.TestCase):
             del self._mkfile
         self._mkfile = None
 
-    def _template(self, name, out_path = None, vars = {}):
-        template_path = os.path.join(self._normal_path, 'pymk', 'tests', 'tmpl', name + '.tpl')
+    def _template(self, name, out_path=None, vars={}):
+        template_path = os.path.join(
+            self._normal_path, 'pymk', 'tests', 'tmpl', name + '.tpl')
         template = open(template_path).read()
-        out_data = template %vars
-        if not out_path:
-            out_path = name
+        out_data = template % vars
         out_file = open(out_path, 'w')
         out_file.write(out_data)
         out_file.close()
 
     def _import_mkfile(self):
-        TaskData.init()
+        TaskMeta.init()
         self._mkfile = import_mkfile()
 
     def _pymk(self):
@@ -69,7 +72,7 @@ class PymkTestCase(unittest.TestCase):
     def _remove_task(self, task):
         self._args.task.remove(task)
 
-    def touch(self, path, wait=0.005):
+    def touch(self, path, wait=0.01):
         if wait:
             sleep(wait)
         touch(path)
